<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>QObject</name>
    <message>
        <location filename="../dbus/launcher1compat.cpp" line="41"/>
        <source>%1 removed successfully</source>
        <translation>%1 видалено успішно</translation>
    </message>
    <message>
        <location filename="../dbus/launcher1compat.cpp" line="43"/>
        <source>Failed to remove the app</source>
        <translation>Не вдалося вилучити програму</translation>
    </message>
</context>
</TS>
